@@ -1,5 +1,5 @@
-from autodiff_107.diff.Node import Node
-from autodiff_107.diff import numpy as np
+from .diff import *
+from .diff import numpy as np
 import pytest
 
 # Testing that we can instantiate nodes ad int, float that we get the correct derivatives
@@ -297,3 +297,11 @@ def test_forward_mode_6():
     assert f._fmd == -np.sin(3)
 
 test_forward_mode_6()
+
+def test_user_derivative_1():
+	x = variable(1)
+	f = lambda x: 3*x-2
+	df = derivative(f(x), x)
+	assert df == 3
+
+test_user_derivative_1
