@@ -1,7 +1,7 @@
-from autodiff_107.diff.Node import Node
-from autodiff_107.diff import variable
-from autodiff_107.diff import numpy
-from autodiff_107.diff import numpy as np
+from .diff import Node
+from .diff import variable
+from .diff import numpy
+from .diff import numpy as np
 import pytest
 
 # Testing logarithm
